@@ -6,6 +6,7 @@ const.werner@gmail.com
 import time
 import re
 import requests
+import pymorphy2
 import copy
 import json
 from nltk.tokenize import word_tokenize
@@ -175,7 +176,7 @@ class UDPipeParser:
   """
 
     def __init__(self, propn_nouns=[], abbrev_dict={}, lang='ru'):
-        self.morph = Morpholog()
+        self.morph = pymorphy2.MorphAnalyzer()
         self.preprocessor = TextPreProcessor(propn_nouns=propn_nouns, abbrev_dict=abbrev_dict)
         self.propn_nouns = propn_nouns
         self.logging = False
